@@ -1,12 +1,12 @@
 package CGI::Builder::Const ;
-$VERSION = 1.25 ;
+$VERSION = 1.26 ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
 
 ; use strict
 
-; my (@prefix, $h)
+; my $h
 ; our (@phase, $END)
 
 ; BEGIN
@@ -22,11 +22,6 @@ $VERSION = 1.25 ;
                     CLEANUP
                   |
    ; @$h{@phase} = (0 .. $#phase)
-   ; @prefix = qw | OH
-                    SH
-                    PH
-                  |
-   ; @$h{@prefix} = map { "$_\_" } @prefix
    ; while ( my ($k, $v) = each %$h )
       { no strict 'refs'
       ; *$k = sub () { $v }
@@ -35,10 +30,9 @@ $VERSION = 1.25 ;
 
 ; require Exporter
 ; our @ISA = 'Exporter'
-; our @EXPORT_OK   = ( @phase, @prefix )
-; our %EXPORT_TAGS = ( all      => [ @phase, @prefix ]
+; our @EXPORT_OK   = ( @phase )
+; our %EXPORT_TAGS = ( all      => \@phase
                      , phases   => \@phase
-                     , prefixes => \@prefix
                      )
                      
 ; 1
@@ -49,9 +43,9 @@ __END__
 
 CGI::Builder::Const - Imports constants
 
-=head1 VERSION 1.25
+=head1 VERSION 1.26
 
-Included in CGI-Builder 1.25 distribution.
+Included in CGI-Builder 1.26 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -104,21 +98,9 @@ These constant are used to set and check the Process Phase. They return just a p
   REDIR           8
   CLEANUP         9
 
-=head2 :prefixes
-
-These constants return the handler prefixes:
-
-  OH  'OH_'
-  PH  'PH_'
-  SH  'SH_'
-
 =head1 SUPPORT
 
-Support for all the modules of the CBF is via the mailing list. The list is used for general support on the use of the CBF, announcements, bug reports, patches, suggestions for improvements or new features. The API to the CBF is stable, but if you use the CBF in a production environment, it's probably a good idea to keep a watch on the list.
-
-You can join the CBF mailing list at this url:
-
-http://lists.sourceforge.net/lists/listinfo/cgi-builder-users
+See L<CGI::Builder/"SUPPORT">.
 
 =head1 AUTHOR and COPYRIGHT
 
